@@ -151,10 +151,16 @@ class GenerateCitationNet():
         if result:
             data = result[0]
             inyear = self.getPubDate(data)
+            tmpDict = {}
+            for key in ['title', 'is-referenced-by-count']:
+                if key in data.keys():
+                    tmpDict[key] = data[key][0]
+                else:
+                    tmpDict[key]
             self.mainNode = (
                 doi,
-                data['title'][0],
-                data['is-referenced-by-count'][0],
+                tmpDict['title'],
+                tmpDict['is-referenced-by-count'],
                 inyear
             )
             return 'Done'
